@@ -172,18 +172,20 @@ func TestStaticAutoscalerRunOnce(t *testing.T) {
 
 	// Create context with mocked lister registry.
 	options := config.AutoscalingOptions{
-		EstimatorName:                       estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:                    true,
-		ScaleDownUtilizationThreshold:       0.5,
-		MaxNodesTotal:                       1,
-		MaxCoresTotal:                       10,
-		MaxMemoryTotal:                      100000,
-		ScaleDownUnreadyTime:                time.Minute,
-		ScaleDownUnneededTime:               time.Minute,
-		FilterOutSchedulablePodsUsesPacking: true,
+		EstimatorName:                 estimator.BinpackingEstimatorName,
+		ScaleDownEnabled:              true,
+		ScaleDownUtilizationThreshold: 0.5,
+		MaxNodesTotal:                 1,
+		MaxCoresTotal:                 10,
+		MaxMemoryTotal:                100000,
+		ScaleDownUnreadyTime:          time.Minute,
+		ScaleDownUnneededTime:         time.Minute,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
+
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -216,7 +218,7 @@ func TestStaticAutoscalerRunOnce(t *testing.T) {
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 	podDisruptionBudgetListerMock.On("List").Return([]*policyv1.PodDisruptionBudget{}, nil).Once()
 
-	err := autoscaler.RunOnce(time.Now())
+	err = autoscaler.RunOnce(time.Now())
 	assert.NoError(t, err)
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
 		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
@@ -285,7 +287,7 @@ func TestStaticAutoscalerRunOnce(t *testing.T) {
 	// Remove unregistered nodes.
 	readyNodeLister.SetNodes([]*apiv1.Node{n1, n2})
 	allNodeLister.SetNodes([]*apiv1.Node{n1, n2})
-	scheduledPodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Once()
+	scheduledPodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Twice()
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 	onScaleDownMock.On("ScaleDown", "ng2", "n3").Return(nil).Once()
 
@@ -307,7 +309,7 @@ func TestStaticAutoscalerRunOnceWithAutoprovisionedEnabled(t *testing.T) {
 	onScaleDownMock := &onScaleDownMock{}
 	onNodeGroupCreateMock := &onNodeGroupCreateMock{}
 	onNodeGroupDeleteMock := &onNodeGroupDeleteMock{}
-	nodeGroupManager := &mockAutoprovisioningNodeGroupManager{t}
+	nodeGroupManager := &mockAutoprovisioningNodeGroupManager{t, 0}
 	nodeGroupListProcessor := &mockAutoprovisioningNodeGroupListProcessor{t}
 
 	n1 := BuildTestNode("n1", 100, 1000)
@@ -356,20 +358,22 @@ func TestStaticAutoscalerRunOnceWithAutoprovisionedEnabled(t *testing.T) {
 
 	// Create context with mocked lister registry.
 	options := config.AutoscalingOptions{
-		EstimatorName:                       estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:                    true,
-		ScaleDownUtilizationThreshold:       0.5,
-		MaxNodesTotal:                       100,
-		MaxCoresTotal:                       100,
-		MaxMemoryTotal:                      100000,
-		ScaleDownUnreadyTime:                time.Minute,
-		ScaleDownUnneededTime:               time.Minute,
-		NodeAutoprovisioningEnabled:         true,
-		MaxAutoprovisionedNodeGroupCount:    10, // Pods with null priority are always non expendable. Test if it works.
-		FilterOutSchedulablePodsUsesPacking: true,
+		EstimatorName:                    estimator.BinpackingEstimatorName,
+		ScaleDownEnabled:                 true,
+		ScaleDownUtilizationThreshold:    0.5,
+		MaxNodesTotal:                    100,
+		MaxCoresTotal:                    100,
+		MaxMemoryTotal:                   100000,
+		ScaleDownUnreadyTime:             time.Minute,
+		ScaleDownUnneededTime:            time.Minute,
+		NodeAutoprovisioningEnabled:      true,
+		MaxAutoprovisionedNodeGroupCount: 10,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
+
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -403,7 +407,7 @@ func TestStaticAutoscalerRunOnceWithAutoprovisionedEnabled(t *testing.T) {
 	onNodeGroupCreateMock.On("Create", "autoprovisioned-TN2").Return(nil).Once()
 	onScaleUpMock.On("ScaleUp", "autoprovisioned-TN2", 1).Return(nil).Once()
 
-	err := autoscaler.RunOnce(time.Now().Add(time.Hour))
+	err = autoscaler.RunOnce(time.Now().Add(time.Hour))
 	assert.NoError(t, err)
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
 		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
@@ -488,19 +492,21 @@ func TestStaticAutoscalerRunOnceWithALongUnregisteredNode(t *testing.T) {
 
 	// Create context with mocked lister registry.
 	options := config.AutoscalingOptions{
-		EstimatorName:                       estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:                    true,
-		ScaleDownUtilizationThreshold:       0.5,
-		MaxNodesTotal:                       10,
-		MaxCoresTotal:                       10,
-		MaxMemoryTotal:                      100000,
-		ScaleDownUnreadyTime:                time.Minute,
-		ScaleDownUnneededTime:               time.Minute,
-		MaxNodeProvisionTime:                10 * time.Second,
-		FilterOutSchedulablePodsUsesPacking: true,
+		EstimatorName:                 estimator.BinpackingEstimatorName,
+		ScaleDownEnabled:              true,
+		ScaleDownUtilizationThreshold: 0.5,
+		MaxNodesTotal:                 10,
+		MaxCoresTotal:                 10,
+		MaxMemoryTotal:                100000,
+		ScaleDownUnreadyTime:          time.Minute,
+		ScaleDownUnneededTime:         time.Minute,
+		MaxNodeProvisionTime:          10 * time.Second,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
+
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -540,7 +546,7 @@ func TestStaticAutoscalerRunOnceWithALongUnregisteredNode(t *testing.T) {
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 	onScaleUpMock.On("ScaleUp", "ng1", 1).Return(nil).Once()
 
-	err := autoscaler.RunOnce(later.Add(time.Hour))
+	err = autoscaler.RunOnce(later.Add(time.Hour))
 	assert.NoError(t, err)
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
 		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
@@ -551,7 +557,7 @@ func TestStaticAutoscalerRunOnceWithALongUnregisteredNode(t *testing.T) {
 
 	readyNodeLister.SetNodes([]*apiv1.Node{n1, n2})
 	allNodeLister.SetNodes([]*apiv1.Node{n1, n2})
-	scheduledPodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Once()
+	scheduledPodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Twice()
 	onScaleDownMock.On("ScaleDown", "ng1", "broken").Return(nil).Once()
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 
@@ -562,116 +568,6 @@ func TestStaticAutoscalerRunOnceWithALongUnregisteredNode(t *testing.T) {
 		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
 }
 
-func TestStaticAutoscalerRunOncePodsWithFilterOutSchedulablePodsUsesPackingFalse(t *testing.T) {
-	readyNodeLister := kubernetes.NewTestNodeLister(nil)
-	allNodeLister := kubernetes.NewTestNodeLister(nil)
-	scheduledPodMock := &podListerMock{}
-	unschedulablePodMock := &podListerMock{}
-	podDisruptionBudgetListerMock := &podDisruptionBudgetListerMock{}
-	daemonSetListerMock := &daemonSetListerMock{}
-	onScaleUpMock := &onScaleUpMock{}
-	onScaleDownMock := &onScaleDownMock{}
-
-	n1 := BuildTestNode("n1", 100, 1000)
-	SetNodeReadyState(n1, true, time.Now())
-	n2 := BuildTestNode("n2", 1000, 1000)
-	SetNodeReadyState(n2, true, time.Now())
-	n3 := BuildTestNode("n3", 1000, 1000)
-	SetNodeReadyState(n3, true, time.Now())
-
-	// shared owner reference
-	ownerRef := GenerateOwnerReferences("rs", "ReplicaSet", "extensions/v1beta1", "")
-
-	p1 := BuildTestPod("p1", 40, 0)
-	p1.OwnerReferences = ownerRef
-	p1.Spec.NodeName = "n1"
-
-	p2 := BuildTestPod("p2", 400, 0)
-	p2.OwnerReferences = ownerRef
-	p2.Spec.NodeName = "n2"
-
-	p3 := BuildTestPod("p3", 400, 0)
-	p3.OwnerReferences = ownerRef
-	p3.Spec.NodeName = "n2"
-
-	p4 := BuildTestPod("p4", 500, 0)
-	p4.OwnerReferences = ownerRef
-
-	p5 := BuildTestPod("p5", 800, 0)
-	p5.OwnerReferences = ownerRef
-	p5.Status.NominatedNodeName = "n3"
-
-	p6 := BuildTestPod("p6", 1000, 0)
-	p6.OwnerReferences = ownerRef
-
-	provider := testprovider.NewTestCloudProvider(
-		func(id string, delta int) error {
-			return onScaleUpMock.ScaleUp(id, delta)
-		}, func(id string, name string) error {
-			return onScaleDownMock.ScaleDown(id, name)
-		})
-	provider.AddNodeGroup("ng1", 0, 10, 1)
-	provider.AddNodeGroup("ng2", 0, 10, 2)
-	provider.AddNode("ng1", n1)
-	provider.AddNode("ng2", n2)
-	provider.AddNode("ng2", n3)
-	assert.NotNil(t, provider)
-	ng2 := reflect.ValueOf(provider.GetNodeGroup("ng2")).Interface().(*testprovider.TestNodeGroup)
-	assert.NotNil(t, ng2)
-
-	// Create context with mocked lister registry.
-	options := config.AutoscalingOptions{
-		EstimatorName:                 estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:              true,
-		ScaleDownUtilizationThreshold: 0.5,
-		MaxNodesTotal:                 10,
-		MaxCoresTotal:                 10,
-		MaxMemoryTotal:                100000,
-		ScaleDownUnreadyTime:          time.Minute,
-		ScaleDownUnneededTime:         time.Minute,
-		ExpendablePodsPriorityCutoff:  10,
-		//Turn off filtering schedulables using packing
-		FilterOutSchedulablePodsUsesPacking: false,
-	}
-	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
-	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
-		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
-		nil, nil, nil, nil)
-	context.ListerRegistry = listerRegistry
-
-	clusterStateConfig := clusterstate.ClusterStateRegistryConfig{
-		OkTotalUnreadyCount:  1,
-		MaxNodeProvisionTime: 10 * time.Second,
-	}
-
-	clusterState := clusterstate.NewClusterStateRegistry(provider, clusterStateConfig, context.LogRecorder, newBackoff())
-	sd := NewScaleDown(&context, clusterState)
-
-	autoscaler := &StaticAutoscaler{
-		AutoscalingContext:    &context,
-		clusterStateRegistry:  clusterState,
-		lastScaleUpTime:       time.Now(),
-		lastScaleDownFailTime: time.Now(),
-		scaleDown:             sd,
-		processors:            NewTestProcessors(),
-		processorCallbacks:    processorCallbacks,
-	}
-
-	// Scale up
-	readyNodeLister.SetNodes([]*apiv1.Node{n1, n2, n3})
-	allNodeLister.SetNodes([]*apiv1.Node{n1, n2, n3})
-	scheduledPodMock.On("List").Return([]*apiv1.Pod{p1, p2, p3}, nil).Times(2) // 1 to get pods + 1 when building nodeInfo map
-	unschedulablePodMock.On("List").Return([]*apiv1.Pod{p4, p5, p6}, nil).Once()
-	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
-	onScaleUpMock.On("ScaleUp", "ng2", 2).Return(nil).Once()
-
-	err := autoscaler.RunOnce(time.Now())
-	assert.NoError(t, err)
-	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
-		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
-}
-
 func TestStaticAutoscalerRunOncePodsWithPriorities(t *testing.T) {
 	readyNodeLister := kubernetes.NewTestNodeLister(nil)
 	allNodeLister := kubernetes.NewTestNodeLister(nil)
@@ -739,19 +635,21 @@ func TestStaticAutoscalerRunOncePodsWithPriorities(t *testing.T) {
 
 	// Create context with mocked lister registry.
 	options := config.AutoscalingOptions{
-		EstimatorName:                       estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:                    true,
-		ScaleDownUtilizationThreshold:       0.5,
-		MaxNodesTotal:                       10,
-		MaxCoresTotal:                       10,
-		MaxMemoryTotal:                      100000,
-		ScaleDownUnreadyTime:                time.Minute,
-		ScaleDownUnneededTime:               time.Minute,
-		ExpendablePodsPriorityCutoff:        10,
-		FilterOutSchedulablePodsUsesPacking: true,
+		EstimatorName:                 estimator.BinpackingEstimatorName,
+		ScaleDownEnabled:              true,
+		ScaleDownUtilizationThreshold: 0.5,
+		MaxNodesTotal:                 10,
+		MaxCoresTotal:                 10,
+		MaxMemoryTotal:                100000,
+		ScaleDownUnreadyTime:          time.Minute,
+		ScaleDownUnneededTime:         time.Minute,
+		ExpendablePodsPriorityCutoff:  10,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
+
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -783,7 +681,7 @@ func TestStaticAutoscalerRunOncePodsWithPriorities(t *testing.T) {
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 	onScaleUpMock.On("ScaleUp", "ng2", 1).Return(nil).Once()
 
-	err := autoscaler.RunOnce(time.Now())
+	err = autoscaler.RunOnce(time.Now())
 	assert.NoError(t, err)
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
 		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
@@ -873,97 +771,10 @@ func TestStaticAutoscalerRunOnceWithFilteringOnBinPackingEstimator(t *testing.T)
 		ExpendablePodsPriorityCutoff:  10,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
-	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
-		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
-		nil, nil, nil, nil)
-	context.ListerRegistry = listerRegistry
 
-	clusterStateConfig := clusterstate.ClusterStateRegistryConfig{
-		OkTotalUnreadyCount:  1,
-		MaxNodeProvisionTime: 10 * time.Second,
-	}
-
-	clusterState := clusterstate.NewClusterStateRegistry(provider, clusterStateConfig, context.LogRecorder, newBackoff())
-	sd := NewScaleDown(&context, clusterState)
-
-	autoscaler := &StaticAutoscaler{
-		AutoscalingContext:    &context,
-		clusterStateRegistry:  clusterState,
-		lastScaleUpTime:       time.Now(),
-		lastScaleDownFailTime: time.Now(),
-		scaleDown:             sd,
-		processors:            NewTestProcessors(),
-		processorCallbacks:    processorCallbacks,
-	}
-
-	// Scale up
-	readyNodeLister.SetNodes([]*apiv1.Node{n1, n2})
-	allNodeLister.SetNodes([]*apiv1.Node{n1, n2})
-	scheduledPodMock.On("List").Return([]*apiv1.Pod{p3, p4}, nil).Times(2) // 1 to get pods + 1 when building nodeInfo map
-	unschedulablePodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Once()
-	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
-
-	err := autoscaler.RunOnce(time.Now())
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
 	assert.NoError(t, err)
 
-	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
-		podDisruptionBudgetListerMock, daemonSetListerMock, onScaleUpMock, onScaleDownMock)
-}
-
-func TestStaticAutoscalerRunOnceWithFilteringOnOldEstimator(t *testing.T) {
-	readyNodeLister := kubernetes.NewTestNodeLister(nil)
-	allNodeLister := kubernetes.NewTestNodeLister(nil)
-	scheduledPodMock := &podListerMock{}
-	unschedulablePodMock := &podListerMock{}
-	podDisruptionBudgetListerMock := &podDisruptionBudgetListerMock{}
-	daemonSetListerMock := &daemonSetListerMock{}
-	onScaleUpMock := &onScaleUpMock{}
-	onScaleDownMock := &onScaleDownMock{}
-
-	n1 := BuildTestNode("n1", 2000, 1000)
-	SetNodeReadyState(n1, true, time.Now())
-	n2 := BuildTestNode("n2", 2000, 1000)
-	SetNodeReadyState(n2, true, time.Now())
-
-	// shared owner reference
-	ownerRef := GenerateOwnerReferences("rs", "ReplicaSet", "extensions/v1beta1", "")
-
-	p1 := BuildTestPod("p1", 1400, 0)
-	p1.OwnerReferences = ownerRef
-	p3 := BuildTestPod("p3", 1400, 0)
-	p3.Spec.NodeName = "n1"
-	p3.OwnerReferences = ownerRef
-	p4 := BuildTestPod("p4", 1400, 0)
-	p4.Spec.NodeName = "n2"
-	p4.OwnerReferences = ownerRef
-
-	provider := testprovider.NewTestCloudProvider(
-		func(id string, delta int) error {
-			return onScaleUpMock.ScaleUp(id, delta)
-		}, func(id string, name string) error {
-			return onScaleDownMock.ScaleDown(id, name)
-		})
-	provider.AddNodeGroup("ng1", 0, 10, 2)
-	provider.AddNode("ng1", n1)
-
-	provider.AddNodeGroup("ng2", 0, 10, 1)
-	provider.AddNode("ng2", n2)
-
-	assert.NotNil(t, provider)
-
-	// Create context with mocked lister registry.
-	options := config.AutoscalingOptions{
-		EstimatorName:                 estimator.OldBinpackingEstimatorName,
-		ScaleDownEnabled:              false,
-		ScaleDownUtilizationThreshold: 0.5,
-		MaxNodesTotal:                 10,
-		MaxCoresTotal:                 10,
-		MaxMemoryTotal:                100000,
-		ExpendablePodsPriorityCutoff:  10,
-	}
-	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -994,7 +805,7 @@ func TestStaticAutoscalerRunOnceWithFilteringOnOldEstimator(t *testing.T) {
 	unschedulablePodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Once()
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 
-	err := autoscaler.RunOnce(time.Now())
+	err = autoscaler.RunOnce(time.Now())
 	assert.NoError(t, err)
 
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
@@ -1053,7 +864,10 @@ func TestStaticAutoscalerRunOnceWithFilteringOnUpcomingNodesEnabledNoScaleUp(t *
 		ExpendablePodsPriorityCutoff:  10,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
+
 	listerRegistry := kube_util.NewListerRegistry(allNodeLister, readyNodeLister, scheduledPodMock,
 		unschedulablePodMock, podDisruptionBudgetListerMock, daemonSetListerMock,
 		nil, nil, nil, nil)
@@ -1084,7 +898,7 @@ func TestStaticAutoscalerRunOnceWithFilteringOnUpcomingNodesEnabledNoScaleUp(t *
 	unschedulablePodMock.On("List").Return([]*apiv1.Pod{p1}, nil).Once()
 	daemonSetListerMock.On("List", labels.Everything()).Return([]*appsv1.DaemonSet{}, nil).Once()
 
-	err := autoscaler.RunOnce(time.Now())
+	err = autoscaler.RunOnce(time.Now())
 	assert.NoError(t, err)
 
 	mock.AssertExpectationsForObjects(t, scheduledPodMock, unschedulablePodMock,
@@ -1098,19 +912,20 @@ func TestStaticAutoscalerInstaceCreationErrors(t *testing.T) {
 
 	// Create context with mocked lister registry.
 	options := config.AutoscalingOptions{
-		EstimatorName:                       estimator.BinpackingEstimatorName,
-		ScaleDownEnabled:                    true,
-		ScaleDownUtilizationThreshold:       0.5,
-		MaxNodesTotal:                       10,
-		MaxCoresTotal:                       10,
-		MaxMemoryTotal:                      100000,
-		ScaleDownUnreadyTime:                time.Minute,
-		ScaleDownUnneededTime:               time.Minute,
-		ExpendablePodsPriorityCutoff:        10,
-		FilterOutSchedulablePodsUsesPacking: true,
+		EstimatorName:                 estimator.BinpackingEstimatorName,
+		ScaleDownEnabled:              true,
+		ScaleDownUtilizationThreshold: 0.5,
+		MaxNodesTotal:                 10,
+		MaxCoresTotal:                 10,
+		MaxMemoryTotal:                100000,
+		ScaleDownUnreadyTime:          time.Minute,
+		ScaleDownUnneededTime:         time.Minute,
+		ExpendablePodsPriorityCutoff:  10,
 	}
 	processorCallbacks := newStaticAutoscalerProcessorCallbacks()
-	context := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+
+	context, err := NewScaleTestAutoscalingContext(options, &fake.Clientset{}, nil, provider, processorCallbacks)
+	assert.NoError(t, err)
 
 	clusterStateConfig := clusterstate.ClusterStateRegistryConfig{
 		OkTotalUnreadyCount:  1,
